summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStefan Fritsch <sf@apache.org>2011-07-23 17:21:02 +0000
committerStefan Fritsch <sf@apache.org>2011-07-23 17:21:02 +0000
commit9674eb32cb74108cceab8ce457b6910fcfe9a479 (patch)
tree348b28d961064bf99a9db7c7d0b4ef2c3af27001
parent6e1307b58e3520fdbc7b16d1c9fd019a6365668f (diff)
downloadhttpd-9674eb32cb74108cceab8ce457b6910fcfe9a479.tar.gz
Revert r1129886:
Shift declaration logic of LDAP_DECLARE to ap_ldap.h from util_ldap.h git-svn-id: https://svn.apache.org/repos/asf/httpd/httpd/branches/revert-ap-ldap@1150169 13f79535-47bb-0310-9956-ffa450edef68
-rw-r--r--include/ap_ldap.h.in32
-rw-r--r--include/ap_ldap_init.h16
-rw-r--r--include/ap_ldap_option.h10
-rw-r--r--include/ap_ldap_rebind.h14
-rw-r--r--include/ap_ldap_url.h12
-rw-r--r--include/util_ldap.h21
-rw-r--r--modules/ldap/ap_ldap_init.c8
-rw-r--r--modules/ldap/ap_ldap_option.c8
-rw-r--r--modules/ldap/ap_ldap_rebind.c6
-rw-r--r--modules/ldap/ap_ldap_url.c10
10 files changed, 77 insertions, 60 deletions
diff --git a/include/ap_ldap.h.in b/include/ap_ldap.h.in
index b847db3da3..e6d69af644 100644
--- a/include/ap_ldap.h.in
+++ b/include/ap_ldap.h.in
@@ -30,27 +30,23 @@
* @{
*/
-/* Create a set of LDAP_DECLARE macros with appropriate export
- * and import tags for the platform
- */
#if !defined(WIN32)
-#define LDAP_DECLARE(type) type
-#define LDAP_DECLARE_NONSTD(type) type
-#define LDAP_DECLARE_DATA
-#elif defined(LDAP_DECLARE_STATIC)
-#define LDAP_DECLARE(type) type __stdcall
-#define LDAP_DECLARE_NONSTD(type) type
-#define LDAP_DECLARE_DATA
-#elif defined(LDAP_DECLARE_EXPORT)
-#define LDAP_DECLARE(type) __declspec(dllexport) type __stdcall
-#define LDAP_DECLARE_NONSTD(type) __declspec(dllexport) type
-#define LDAP_DECLARE_DATA __declspec(dllexport)
+#define MODLDAP_DECLARE(type) type
+#define MODLDAP_DECLARE_NONSTD(type) type
+#define MODLDAP_DECLARE_DATA
+#elif defined(MODLDAP_DECLARE_STATIC)
+#define MODLDAP_DECLARE(type) type __stdcall
+#define MODLDAP_DECLARE_NONSTD(type) type
+#define MODLDAP_DECLARE_DATA
+#elif defined(MODLDAP_DECLARE_EXPORT)
+#define MODLDAP_DECLARE(type) __declspec(dllexport) type __stdcall
+#define MODLDAP_DECLARE_NONSTD(type) __declspec(dllexport) type
+#define MODLDAP_DECLARE_DATA __declspec(dllexport)
#else
-#define LDAP_DECLARE(type) __declspec(dllimport) type __stdcall
-#define LDAP_DECLARE_NONSTD(type) __declspec(dllimport) type
-#define LDAP_DECLARE_DATA __declspec(dllimport)
+#define MODLDAP_DECLARE(type) __declspec(dllimport) type __stdcall
+#define MODLDAP_DECLARE_NONSTD(type) __declspec(dllimport) type
+#define MODLDAP_DECLARE_DATA __declspec(dllimport)
#endif
-
/* this will be defined if LDAP support was compiled into apr-util */
#define AP_HAS_LDAP @ap_has_ldap@
diff --git a/include/ap_ldap_url.h b/include/ap_ldap_url.h
index d8c4095822..9f2bca1d08 100644
--- a/include/ap_ldap_url.h
+++ b/include/ap_ldap_url.h
@@ -16,7 +16,7 @@
/**
* @file ap_ldap_url.h
- * @brief LDAP ldap_init() functions
+ * @brief MODLDAP ldap_init() functions
*/
#ifndef AP_LDAP_URL_H
#define AP_LDAP_URL_H
@@ -71,19 +71,19 @@ typedef struct ap_ldap_url_desc_t {
* Is this URL an ldap url? ldap://
* @param url The url to test
*/
-LDAP_DECLARE(int) ap_ldap_is_ldap_url(const char *url);
+MODLDAP_DECLARE(int) ap_ldap_is_ldap_url(const char *url);
/**
* Is this URL an SSL ldap url? ldaps://
* @param url The url to test
*/
-LDAP_DECLARE(int) ap_ldap_is_ldaps_url(const char *url);
+MODLDAP_DECLARE(int) ap_ldap_is_ldaps_url(const char *url);
/**
* Is this URL an ldap socket url? ldapi://
* @param url The url to test
*/
-LDAP_DECLARE(int) ap_ldap_is_ldapi_url(const char *url);
+MODLDAP_DECLARE(int) ap_ldap_is_ldapi_url(const char *url);
/**
* Parse an LDAP URL.
@@ -92,7 +92,7 @@ LDAP_DECLARE(int) ap_ldap_is_ldapi_url(const char *url);
* @param ludpp The structure to return the exploded URL
* @param result_err The result structure of the operation
*/
-LDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
const char *url_in,
ap_ldap_url_desc_t **ludpp,
ap_ldap_err_t **result_err);
@@ -104,7 +104,7 @@ LDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
* @param ludpp The structure to return the exploded URL
* @param result_err The result structure of the operation
*/
-LDAP_DECLARE(int) ap_ldap_url_parse(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_url_parse(apr_pool_t *pool,
const char *url_in,
ap_ldap_url_desc_t **ludpp,
ap_ldap_err_t **result_err);
diff --git a/include/util_ldap.h b/include/util_ldap.h
index 5ee3fb6043..2ab4b7eb3f 100644
--- a/include/util_ldap.h
+++ b/include/util_ldap.h
@@ -56,6 +56,27 @@
#include "http_request.h"
#include "apr_optional.h"
+/* Create a set of LDAP_DECLARE macros with appropriate export
+ * and import tags for the platform
+ */
+#if !defined(WIN32)
+#define LDAP_DECLARE(type) type
+#define LDAP_DECLARE_NONSTD(type) type
+#define LDAP_DECLARE_DATA
+#elif defined(LDAP_DECLARE_STATIC)
+#define LDAP_DECLARE(type) type __stdcall
+#define LDAP_DECLARE_NONSTD(type) type
+#define LDAP_DECLARE_DATA
+#elif defined(LDAP_DECLARE_EXPORT)
+#define LDAP_DECLARE(type) __declspec(dllexport) type __stdcall
+#define LDAP_DECLARE_NONSTD(type) __declspec(dllexport) type
+#define LDAP_DECLARE_DATA __declspec(dllexport)
+#else
+#define LDAP_DECLARE(type) __declspec(dllimport) type __stdcall
+#define LDAP_DECLARE_NONSTD(type) __declspec(dllimport) type
+#define LDAP_DECLARE_DATA __declspec(dllimport)
+#endif
+
#ifdef __cplusplus
extern "C" {
#endif
diff --git a/modules/ldap/ap_ldap_init.c b/modules/ldap/ap_ldap_init.c
index 4802290251..ec34904e46 100644
--- a/modules/ldap/ap_ldap_init.c
+++ b/modules/ldap/ap_ldap_init.c
@@ -51,7 +51,7 @@
* will return APR_EGENERAL. Further LDAP specific error information
* can be found in result_err.
*/
-LDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
const char *cert_auth_file,
int cert_file_type,
ap_ldap_err_t **result_err)
@@ -108,7 +108,7 @@ LDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
* @todo currently we do not check whether ap_ldap_ssl_init()
* has been called first - should we?
*/
-LDAP_DECLARE(int) ap_ldap_ssl_deinit(void)
+MODLDAP_DECLARE(int) ap_ldap_ssl_deinit(void)
{
#if AP_HAS_LDAP_SSL && AP_HAS_LDAPSSL_CLIENT_DEINIT
@@ -139,7 +139,7 @@ LDAP_DECLARE(int) ap_ldap_ssl_deinit(void)
* AP_LDAP_SSL: SSL encryption (ldaps://)
* AP_LDAP_STARTTLS: Force STARTTLS on ldap://
*/
-LDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
LDAP **ldap,
const char *hostname,
int portno,
@@ -179,7 +179,7 @@ LDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
* This function returns a string describing the LDAP toolkit
* currently in use. The string is placed inside result_err->reason.
*/
-LDAP_DECLARE(int) ap_ldap_info(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_info(apr_pool_t *pool,
ap_ldap_err_t **result_err)
{
ap_ldap_err_t *result = (ap_ldap_err_t *)apr_pcalloc(pool, sizeof(ap_ldap_err_t));
diff --git a/modules/ldap/ap_ldap_rebind.c b/modules/ldap/ap_ldap_rebind.c
index 230986ef6b..0b93abc9d9 100644
--- a/modules/ldap/ap_ldap_rebind.c
+++ b/modules/ldap/ap_ldap_rebind.c
@@ -67,7 +67,7 @@ static apr_status_t ap_ldap_pool_cleanup_set_null(void *data_)
/* AP utility routine used to create the xref_lock. */
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool)
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool)
{
apr_status_t retcode = APR_SUCCESS;
@@ -89,7 +89,7 @@ LDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool)
}
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
LDAP *ld,
const char *bindDN,
const char *bindPW)
@@ -147,7 +147,7 @@ LDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
}
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_remove(LDAP *ld)
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_remove(LDAP *ld)
{
ap_ldap_rebind_entry_t *tmp_xref, *prev = NULL;
apr_status_t retcode = 0;
diff --git a/modules/ldap/ap_ldap_url.c b/modules/ldap/ap_ldap_url.c
index 8317990c75..f1fe2166ee 100644
--- a/modules/ldap/ap_ldap_url.c
+++ b/modules/ldap/ap_ldap_url.c
@@ -115,7 +115,7 @@ static char **ap_ldap_str2charray(apr_pool_t *pool,
* Is this URL an ldap url?
*
*/
-LDAP_DECLARE(int) ap_ldap_is_ldap_url(const char *url)
+MODLDAP_DECLARE(int) ap_ldap_is_ldap_url(const char *url)
{
int enclosed;
const char * scheme;
@@ -135,7 +135,7 @@ LDAP_DECLARE(int) ap_ldap_is_ldap_url(const char *url)
* Is this URL a secure ldap url?
*
*/
-LDAP_DECLARE(int) ap_ldap_is_ldaps_url(const char *url)
+MODLDAP_DECLARE(int) ap_ldap_is_ldaps_url(const char *url)
{
int enclosed;
const char * scheme;
@@ -155,7 +155,7 @@ LDAP_DECLARE(int) ap_ldap_is_ldaps_url(const char *url)
* Is this URL an ldap socket url?
*
*/
-LDAP_DECLARE(int) ap_ldap_is_ldapi_url(const char *url)
+MODLDAP_DECLARE(int) ap_ldap_is_ldapi_url(const char *url)
{
int enclosed;
const char * scheme;
@@ -257,7 +257,7 @@ static int str2scope(const char *p)
* The LDAP result code and reason string is returned in the
* ap_ldap_err_t structure.
*/
-LDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
const char *url_in,
ap_ldap_url_desc_t **ludpp,
ap_ldap_err_t **result_err)
@@ -580,7 +580,7 @@ LDAP_DECLARE(int) ap_ldap_url_parse_ext(apr_pool_t *pool,
* The LDAP result code and reason string is returned in the
* ap_ldap_err_t structure.
*/
-LDAP_DECLARE(int) ap_ldap_url_parse(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_url_parse(apr_pool_t *pool,
const char *url_in,
ap_ldap_url_desc_t **ludpp,
ap_ldap_err_t **result_err)
diff --git a/include/ap_ldap_init.h b/include/ap_ldap_init.h
index ce2ae2c0a6..799eedd977 100644
--- a/include/ap_ldap_init.h
+++ b/include/ap_ldap_init.h
@@ -64,7 +64,7 @@ extern "C" {
/**
* LDAP SSL Initialise function
*
* This function initialises SSL on the underlying LDAP toolkit
* if this is necessary.
@@ -86,13 +86,13 @@ extern "C" {
* ap_ldap_set_option() AP_LDAP_OPT_TLS_CERT option for details.
* @param result_err The returned result
*/
-LDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
const char *cert_auth_file,
int cert_file_type,
ap_ldap_err_t **result_err);
/**
* LDAP SSL De-Initialise function
*
* This function tears down any SSL certificate setup previously
* set using ap_ldap_ssl_init(). It should be called to clean
@@ -100,10 +100,10 @@ LDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
* @todo currently we do not check whether ap_ldap_ssl_init()
* has been called first - we probably should.
*/
-LDAP_DECLARE(int) ap_ldap_ssl_deinit(void);
+MODLDAP_DECLARE(int) ap_ldap_ssl_deinit(void);
/**
* LDAP initialise function
*
* This function is responsible for initialising an LDAP
* connection in a toolkit independant way. It does the
@@ -136,7 +136,7 @@ LDAP_DECLARE(int) ap_ldap_ssl_deinit(void);
* @param secure The security mode to set
* @param result_err The returned result
*/
-LDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
LDAP **ldap,
const char *hostname,
int portno,
@@ -144,14 +144,14 @@ LDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
ap_ldap_err_t **result_err);
/**
* LDAP info function
*
* This function returns a string describing the LDAP toolkit
* currently in use. The string is placed inside result_err->reason.
* @param pool The pool to use
* @param result_err The returned result
*/
-LDAP_DECLARE(int) ap_ldap_info(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_info(apr_pool_t *pool,
ap_ldap_err_t **result_err);
#ifdef __cplusplus
@@ -64,7 +64,7 @@ extern "C" {
/**
- * LDAP SSL Initialise function
+ * MODLDAP SSL Initialise function
*
* This function initialises SSL on the underlying LDAP toolkit
@@ -86,13 +86,13 @@ extern "C" {
ap_ldap_err_t **result_err);
/**
- * LDAP SSL De-Initialise function
+ * MODLDAP SSL De-Initialise function
*
* This function tears down any SSL certificate setup previously
@@ -100,10 +100,10 @@ LDAP_DECLARE(int) ap_ldap_ssl_init(apr_pool_t *pool,
/**
- * LDAP initialise function
+ * MODLDAP initialise function
*
* This function is responsible for initialising an LDAP
@@ -144,14 +144,14 @@ LDAP_DECLARE(int) ap_ldap_init(apr_pool_t *pool,
ap_ldap_err_t **result_err);
/**
- * LDAP info function
+ * MODLDAP info function
*
* This function returns a string describing the LDAP toolkit
diff --git a/include/ap_ldap_option.h b/include/ap_ldap_option.h
index 9c4898a225..ba6d995892 100644
--- a/include/ap_ldap_option.h
+++ b/include/ap_ldap_option.h
@@ -16,7 +16,7 @@
/**
* @file ap_ldap_option.h
- * @brief LDAP ldap_*_option() functions
+ * @brief MODLDAP ldap_*_option() functions
*/
#ifndef AP_LDAP_OPTION_H
#define AP_LDAP_OPTION_H
@@ -203,7 +203,7 @@ struct ap_ldap_opt_tls_cert_t {
#define AP_LDAP_STOPTLS 3
/**
* LDAP get option function
*
* This function gets option values from a given LDAP session if
* one was specified. It maps to the native ldap_get_option() function.
@@ -214,14 +214,14 @@ struct ap_ldap_opt_tls_cert_t {
* @param result_err The ap_ldap_err_t structure contained detailed results
* of the operation.
*/
-LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
LDAP *ldap,
int option,
void *outvalue,
ap_ldap_err_t **result_err);
/**
* LDAP set option function
*
* This function sets option values to a given LDAP session if
* one was specified. It maps to the native ldap_set_option() function.
@@ -236,7 +236,7 @@ LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
* @param result_err The ap_ldap_err_t structure contained detailed results
* of the operation.
*/
-LDAP_DECLARE(int) ap_ldap_set_option(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_set_option(apr_pool_t *pool,
LDAP *ldap,
int option,
const void *invalue,
@@ -203,7 +203,7 @@ struct ap_ldap_opt_tls_cert_t {
#define AP_LDAP_STOPTLS 3
/**
- * LDAP get option function
+ * MODLDAP get option function
*
* This function gets option values from a given LDAP session if
@@ -214,14 +214,14 @@ struct ap_ldap_opt_tls_cert_t {
ap_ldap_err_t **result_err);
/**
- * LDAP set option function
+ * MODLDAP set option function
*
* This function sets option values to a given LDAP session if
diff --git a/include/ap_ldap_rebind.h b/include/ap_ldap_rebind.h
index 5601a861ea..91c30e380d 100644
--- a/include/ap_ldap_rebind.h
+++ b/include/ap_ldap_rebind.h
@@ -15,7 +15,7 @@
*/
/**
* The LDAP rebind functions provide an implementation of
* a rebind procedure that can be used to allow clients to chase referrals,
* using the same credentials used to log in originally.
*
@@ -43,16 +43,16 @@
#if AP_HAS_LDAP
/**
* LDAP initialize rebind lock
*
* This function creates the lock for controlling access to the xref list..
* @param pool Pool to use when creating the xref_lock.
*/
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool);
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool);
/**
- * LDAP rebind_add function
+ * MODLDAP rebind_add function
*
* This function creates a cross reference entry for the specified ldap
* connection. The rebind callback function will look up this ldap
@@ -72,13 +72,13 @@ LDAP_DECLARE(apr_status_t) ap_ldap_rebind_init(apr_pool_t *pool);
* @param bindPW The bind Password to be used for any binds while
* chasing referrals on this ldap connection.
*/
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
LDAP *ld,
const char *bindDN,
const char *bindPW);
/**
- * LDAP rebind_remove function
+ * MODLDAP rebind_remove function
*
* This function removes the rebind cross reference entry for the
* specified ldap connection.
@@ -88,7 +88,7 @@ LDAP_DECLARE(apr_status_t) ap_ldap_rebind_add(apr_pool_t *pool,
*
* @param ld The LDAP connectionhandle
*/
-LDAP_DECLARE(apr_status_t) ap_ldap_rebind_remove(LDAP *ld);
+MODLDAP_DECLARE(apr_status_t) ap_ldap_rebind_remove(LDAP *ld);
#endif /* AP_HAS_LDAP */
@@ -15,7 +15,7 @@
*/
/**
- * The LDAP rebind functions provide an implementation of
+ * The MODLDAP rebind functions provide an implementation of
* a rebind procedure that can be used to allow clients to chase referrals,
* using the same credentials used to log in originally.
@@ -43,16 +43,16 @@
#if AP_HAS_LDAP
/**
- * LDAP initialize rebind lock
+ * MODLDAP initialize rebind lock
*
* This function creates the lock for controlling access to the xref list..
diff --git a/modules/ldap/ap_ldap_option.c b/modules/ldap/ap_ldap_option.c
index d38ad21b07..84e770dc4b 100644
--- a/modules/ldap/ap_ldap_option.c
+++ b/modules/ldap/ap_ldap_option.c
@@ -38,12 +38,12 @@ static void option_set_tls(apr_pool_t *pool, LDAP *ldap, const void *invalue,
ap_ldap_err_t *result);
/**
* LDAP get option function
*
* This function gets option values from a given LDAP session if
* one was specified.
*/
-LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
LDAP *ldap,
int option,
void *outvalue,
@@ -72,7 +72,7 @@ LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
}
/**
* LDAP set option function
*
* This function sets option values to a given LDAP session if
* one was specified.
@@ -81,7 +81,7 @@ LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
* will try and apply legacy functions to achieve the same effect,
* depending on the platform.
*/
-LDAP_DECLARE(int) ap_ldap_set_option(apr_pool_t *pool,
+MODLDAP_DECLARE(int) ap_ldap_set_option(apr_pool_t *pool,
LDAP *ldap,
int option,
const void *invalue,
@@ -38,12 +38,12 @@ static void option_set_tls(apr_pool_t *pool, LDAP *ldap, const void *invalue,
ap_ldap_err_t *result);
/**
- * LDAP get option function
+ * MODLDAP get option function
*
* This function gets option values from a given LDAP session if
@@ -72,7 +72,7 @@ LDAP_DECLARE(int) ap_ldap_get_option(apr_pool_t *pool,
}
/**
- * LDAP set option function
+ * MODLDAP set option function
*
* This function sets option values to a given LDAP session if